@@ -1006,11 +1006,17 @@ class NumerousAdminClient(NumerousClient):
     def get_execution_status(self, exe_id):
         return self._job_manager.GetExecutionStatus(spm_pb2.ExecutionId(execution_id=exe_id)).json
 
-    def update_job_by_backend(self, project, scenario, job, exe, message, status, log, complete):
+    def update_job_by_backend(self, project, scenario, job, exe, message, status, log=None, complete=False):
         self._base_client.SetScenarioProgress(spm_pb2.ScenarioProgress(
             project=project, scenario=scenario, spm_job_id=job,
-            message=message, status=status, clean=True, progress=0
+            message=message, status=status, progress=0
         ))
+
+        if log is not None:
+            self._base_client.PushScenarioLogEntry(spm_pb2.ScenarioLogEntry(
+                project=project, scenario=scenario, spm_job_id=job, initialize=False, message=log
+            ))
+
         if complete:
             self._base_client.CompleteExecution(
                 spm_pb2.ExecutionMessage(project_id=project, scenario_id=scenario, job_id=job,
